@@ -3,7 +3,7 @@ from serpapi.serp_api_client import *
 class EbaySearchResults(SerpApiClient):
     """EbaySearchResults enables to search ebay and parse the result.
     ```python
-    from serpapi.ebay_search_results import EbaySearchResults
+    from serpapi import EbaySearchResults
     query = EbaySearchResults({"_nkw": "coffee"})
     data = query.get_json()
     ```
