@@ -3,7 +3,7 @@ from serpapi.serp_api_client import *
 class GoogleSearchResults(SerpApiClient):
     """GoogleSearchResults enables to search google and parse the result.
     ```python
-    from serpapi.google_search_results import GoogleSearchResults
+    from serpapi import GoogleSearchResults
     query = GoogleSearchResults({"q": "coffee", "location": "Austin,Texas"})
     data = query.get_json()
     ```
