@@ -3,7 +3,7 @@ from serpapi.serp_api_client import *
 class YahooSearchResults(SerpApiClient):
     """YahooSearchResults enables to search yahoo and parse the result.
     ```python
-    from serpapi.yahoo_search_results import YahooSearchResults
+    from serpapi import YahooSearchResults
     query = YahooSearchResults({"p": "coffee"})
     data = query.get_json()
     ```
