@@ -2,7 +2,7 @@ import random
 import unittest
 import os
 import pprint
-from serpapi.yandex_search_results import YandexSearchResults
+from serpapi import YandexSearchResults
 
 class TestYandexSearchApi(unittest.TestCase):
 
